"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _momentTimezone = _interopRequireDefault(require("moment-timezone"));

var _coreUtils = _interopRequireDefault(require("@opentripplanner/core-utils"));

var _react = _interopRequireDefault(require("react"));

var _reactIntl = require("react-intl");

var _reactRedux = require("react-redux");

var _fieldTripItineraryGroupSize = _interopRequireDefault(require("../../admin/field-trip-itinerary-group-size"));

var _narrativeItinerary = _interopRequireDefault(require("../narrative-itinerary"));

var _connectedItineraryBody = _interopRequireDefault(require("../line-itin/connected-itinerary-body"));

var _simpleRealtimeAnnotation = _interopRequireDefault(require("../simple-realtime-annotation"));

var _state = require("../../../util/state");

var _itinerarySummary = _interopRequireDefault(require("./itinerary-summary"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  isBicycle,
  isMicromobility,
  isTransit
} = _coreUtils.default.itinerary;
/**
 * Obtains the description of an itinerary in the given locale.
 */

function ItineraryDescription({
  itinerary
}) {
  let primaryTransitDuration = 0;
  let accessModeId = 'walk';
  let transitMode;
  itinerary.legs.forEach((leg, i) => {
    const {
      duration,
      mode,
      rentedBike,
      rentedVehicle
    } = leg;

    if (isTransit(mode) && duration > primaryTransitDuration) {
      // TODO: convert OTP's TRAM mode to the correct wording for Portland
      primaryTransitDuration = duration;
      transitMode = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
        id: `common.otpTransitModes.${mode.toLowerCase()}`
      });
    }

    if (isBicycle(mode)) accessModeId = 'bike';
    if (isMicromobility(mode)) accessModeId = 'micromobility';
    if (rentedVehicle) accessModeId = 'micromobilityRent';
    if (rentedBike) accessModeId = 'bikeshare';
    if (mode === 'CAR') accessModeId = 'drive';
  });

  const mainMode = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: `common.accessModes.${accessModeId}`
  });

  return transitMode ? /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: "components.DefaultItinerary.multiModeSummary",
    values: {
      accessMode: mainMode,
      transitMode
    }
  }) : mainMode;
}
/**
 * Formats the given duration according to the selected locale.
 */


function FormattedDuration({
  duration
}) {
  const dur = _momentTimezone.default.duration(duration, 'seconds');

  const hours = dur.hours();
  const minutes = dur.minutes();

  if (hours === 0) {
    return /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.DefaultItinerary.tripDurationFormatZeroHours",
      values: {
        minutes
      }
    });
  } else {
    return /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.DefaultItinerary.tripDurationFormat",
      values: {
        hours,
        minutes
      }
    });
  }
}

function FormattedTime({
  endTime,
  startTime,
  timeFormat
}) {
  return /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: "components.DefaultItinerary.departureArrivalTimes",
    values: {
      endTime: (0, _momentTimezone.default)(endTime).format(timeFormat),
      startTime: (0, _momentTimezone.default)(startTime).format(timeFormat)
    }
  });
}

const ITINERARY_ATTRIBUTES = [{
  alias: 'best',
  id: 'duration',
  order: 0,
  render: (itinerary, options) => /*#__PURE__*/_react.default.createElement(FormattedDuration, {
    duration: itinerary.duration
  })
}, {
  alias: 'departureTime',
  id: 'arrivalTime',
  order: 1,
  render: (itinerary, options) => {
    if (options.isSelected) {
      if (options.selection === 'ARRIVALTIME') {
        return /*#__PURE__*/_react.default.createElement(FormattedTime, {
          endTime: itinerary.endTime,
          timeFormat: options.timeFormat
        });
      } else {
        return /*#__PURE__*/_react.default.createElement(FormattedTime, {
          startTime: itinerary.startTime,
          timeFormat: options.timeFormat
        });
      }
    }

    return /*#__PURE__*/_react.default.createElement(FormattedTime, {
      endTime: itinerary.endTime,
      startTime: itinerary.startTime,
      timeFormat: options.timeFormat
    });
  }
}, {
  id: 'cost',
  order: 2,
  render: (itinerary, options) => {
    return /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedNumber, {
      currency: options.currency,
      currencyDisplay: "narrowSymbol",
      style: "currency",
      value: (0, _state.getTotalFare)(itinerary, options.configCosts) / 100
    });
  }
}, {
  id: 'walkTime',
  order: 3,
  render: (itinerary, options) => {
    const leg = itinerary.legs[0];
    const {
      LegIcon
    } = options;
    return (
      /*#__PURE__*/
      // FIXME: For CAR mode, walk time considers driving time.
      _react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(FormattedDuration, {
        duration: itinerary.walkTime
      }), ' ', /*#__PURE__*/_react.default.createElement("div", {
        style: {
          display: 'inline-block',
          height: '20px',
          paddingBottom: '6px',
          paddingLeft: '2px',
          width: '20px'
        }
      }, /*#__PURE__*/_react.default.createElement(LegIcon, {
        leg: leg,
        size: 5
      })))
    );
  }
}];

class DefaultItinerary extends _narrativeItinerary.default {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "_onMouseEnter", () => {
      const {
        active,
        index,
        setVisibleItinerary,
        visibleItinerary
      } = this.props; // Set this itinerary as visible if not already visible.

      const visibleNotSet = visibleItinerary === null || visibleItinerary === undefined;
      const isVisible = visibleItinerary === index || active === index && visibleNotSet;

      if (typeof setVisibleItinerary === 'function' && !isVisible) {
        setVisibleItinerary({
          index
        });
      }
    });

    _defineProperty(this, "_onMouseLeave", () => {
      const {
        index,
        setVisibleItinerary,
        visibleItinerary
      } = this.props;

      if (typeof setVisibleItinerary === 'function' && visibleItinerary === index) {
        setVisibleItinerary({
          index: null
        });
      }
    });

    _defineProperty(this, "_isSortingOnAttribute", attribute => {
      const {
        sort
      } = this.props;

      if (sort && sort.type) {
        const type = sort.type.toLowerCase();
        return attribute.id.toLowerCase() === type || attribute.alias && attribute.alias.toLowerCase() === type;
      }

      return false;
    });
  }

  render() {
    const {
      active,
      configCosts,
      currency,
      expanded,
      itinerary,
      LegIcon,
      setActiveLeg,
      showRealtimeAnnotation,
      timeFormat,
      use24HourFormat
    } = this.props;
    const timeOptions = {
      format: timeFormat,
      offset: _coreUtils.default.itinerary.getTimeZoneOffset(itinerary)
    };
    return /*#__PURE__*/_react.default.createElement("div", {
      className: `option default-itin${active ? ' active' : ''}${expanded ? ' expanded' : ''}`,
      onMouseEnter: this._onMouseEnter,
      onMouseLeave: this._onMouseLeave,
      role: "presentation" // FIXME: Move style to css
      ,
      style: {
        backgroundColor: expanded ? 'white' : undefined,
        borderLeft: active && !expanded ? '4px teal solid' : undefined
      }
    }, /*#__PURE__*/_react.default.createElement("button", {
      className: "header" // _onHeaderClick comes from super component (NarrativeItinerary).
      ,
      onClick: this._onHeaderClick
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: "title"
    }, /*#__PURE__*/_react.default.createElement(ItineraryDescription, {
      itinerary: itinerary
    })), /*#__PURE__*/_react.default.createElement("ul", {
      className: "list-unstyled itinerary-attributes"
    }, ITINERARY_ATTRIBUTES.sort((a, b) => {
      const aSelected = this._isSortingOnAttribute(a);

      const bSelected = this._isSortingOnAttribute(b);

      if (aSelected) return -1;
      if (bSelected) return 1;else return a.order - b.order;
    }).map(attribute => {
      const isSelected = this._isSortingOnAttribute(attribute);

      const options = attribute.id === 'arrivalTime' ? timeOptions : {};

      if (isSelected) {
        options.isSelected = true;
        options.selection = this.props.sort.type;
      }

      options.LegIcon = LegIcon;
      options.timeFormat = use24HourFormat ? 'H:mm' : 'h:mm a';
      options.configCosts = configCosts;
      options.currency = currency;
      return /*#__PURE__*/_react.default.createElement("li", {
        className: `${attribute.id}${isSelected ? ' main' : ''}`,
        key: attribute.id
      }, attribute.render(itinerary, options));
    })), /*#__PURE__*/_react.default.createElement(_itinerarySummary.default, {
      itinerary: itinerary,
      LegIcon: LegIcon
    }), /*#__PURE__*/_react.default.createElement(_fieldTripItineraryGroupSize.default, {
      itinerary: itinerary
    }), active && !expanded && /*#__PURE__*/_react.default.createElement("small", {
      style: {
        clear: 'both',
        color: 'grey',
        display: 'block',
        textAlign: 'center'
      }
    }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
      id: "components.DefaultItinerary.clickDetails"
    }))), active && expanded && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, showRealtimeAnnotation && /*#__PURE__*/_react.default.createElement(_simpleRealtimeAnnotation.default, null), /*#__PURE__*/_react.default.createElement(_connectedItineraryBody.default, {
      itinerary: itinerary,
      LegIcon: LegIcon,
      setActiveLeg: setActiveLeg,
      timeOptions: timeOptions
    })));
  }

}

const mapStateToProps = (state, ownProps) => {
  var _state$otp$config$iti, _state$otp$config$loc, _state$user$loggedInU, _state$user$loggedInU2;

  return {
    configCosts: (_state$otp$config$iti = state.otp.config.itinerary) === null || _state$otp$config$iti === void 0 ? void 0 : _state$otp$config$iti.costs,
    // The configured (ambient) currency is needed for rendering the cost
    // of itineraries whether they include a fare or not, in which case
    // we show $0.00 or its equivalent in the configured currency and selected locale.
    currency: ((_state$otp$config$loc = state.otp.config.localization) === null || _state$otp$config$loc === void 0 ? void 0 : _state$otp$config$loc.currency) || 'USD',
    use24HourFormat: (_state$user$loggedInU = (_state$user$loggedInU2 = state.user.loggedInUser) === null || _state$user$loggedInU2 === void 0 ? void 0 : _state$user$loggedInU2.use24HourFormat) !== null && _state$user$loggedInU !== void 0 ? _state$user$loggedInU : false
  };
};

var _default = (0, _reactRedux.connect)(mapStateToProps)(DefaultItinerary);

exports.default = _default;
module.exports = exports.default;

//# sourceMappingURL=default-itinerary.js