"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = NarrativeItinerariesHeader;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _icon = _interopRequireDefault(require("../narrative/icon"));

var _planFirstLastButtons = _interopRequireDefault(require("./plan-first-last-buttons"));

var _saveTripButton = _interopRequireDefault(require("./save-trip-button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const IssueButton = _styledComponents.default.button`
  background-color: #ECBE03;
  border: none;
  border-radius: 5px;
  display: inline-block;
  font-size: 12px;
  padding: 2px 4px;
`;

function NarrativeItinerariesHeader({
  errors,
  itineraries,
  itineraryIsExpanded,
  onSortChange,
  onSortDirChange,
  onToggleShowErrors,
  onViewAllOptions,
  pending,
  showingErrors,
  sort
}) {
  let resultText, titleText;

  if (pending) {
    resultText = 'Finding your options...';
    titleText = 'Finding your options...';
  } else {
    const itineraryPlural = itineraries.length === 1 ? 'itinerary' : 'itineraries';
    const issuePlural = errors.length === 1 ? 'issue' : 'issues';
    resultText = `${itineraries.length} ${itineraryPlural} found.`;
    titleText = errors.length > 0 ? `${itineraries.length} ${itineraryPlural} (and ${errors.length} ${issuePlural}) found` : resultText;
  }

  return /*#__PURE__*/_react.default.createElement("div", {
    className: "options header",
    style: {
      alignItems: 'end',
      display: 'flex',
      flexWrap: 'wrap'
    }
  }, itineraryIsExpanded || showingErrors ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("button", {
    className: "clear-button-formatting",
    onClick: onViewAllOptions
  }, /*#__PURE__*/_react.default.createElement(_icon.default, {
    type: "arrow-left"
  }), " View all options"), itineraryIsExpanded &&
  /*#__PURE__*/
  // marginLeft: auto is a way of making something "float right"
  // within a flex container
  // see https://stackoverflow.com/a/36182782/269834
  _react.default.createElement("div", {
    style: {
      marginLeft: 'auto'
    }
  }, /*#__PURE__*/_react.default.createElement(_saveTripButton.default, null))) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    style: {
      flexGrow: 1
    },
    title: titleText
  }, /*#__PURE__*/_react.default.createElement("span", {
    style: {
      marginRight: '10px'
    }
  }, resultText), errors.length > 0 && /*#__PURE__*/_react.default.createElement(IssueButton, {
    onClick: onToggleShowErrors
  }, /*#__PURE__*/_react.default.createElement(_icon.default, {
    style: {
      fontSize: 11,
      marginRight: 2
    },
    type: "warning"
  }), /*#__PURE__*/_react.default.createElement("span", null, errors.length, " issues"))), /*#__PURE__*/_react.default.createElement("div", {
    style: {
      display: 'flex',
      float: 'right'
    }
  }, /*#__PURE__*/_react.default.createElement("button", {
    className: "clear-button-formatting",
    onClick: onSortDirChange,
    style: {
      marginRight: '5px'
    }
  }, /*#__PURE__*/_react.default.createElement(_icon.default, {
    type: `sort-amount-${sort.direction.toLowerCase()}`
  })), /*#__PURE__*/_react.default.createElement("select", {
    onBlur: onSortChange,
    onChange: onSortChange,
    value: sort.type
  }, /*#__PURE__*/_react.default.createElement("option", {
    value: "BEST"
  }, "Best option"), /*#__PURE__*/_react.default.createElement("option", {
    value: "DURATION"
  }, "Duration"), /*#__PURE__*/_react.default.createElement("option", {
    value: "ARRIVALTIME"
  }, "Arrival time"), /*#__PURE__*/_react.default.createElement("option", {
    value: "DEPARTURETIME"
  }, "Departure time"), /*#__PURE__*/_react.default.createElement("option", {
    value: "WALKTIME"
  }, "Walk time"), /*#__PURE__*/_react.default.createElement("option", {
    value: "COST"
  }, "Cost"))), /*#__PURE__*/_react.default.createElement(_planFirstLastButtons.default, null)));
}

module.exports = exports.default;

//# sourceMappingURL=narrative-itineraries-header.js